"use strict";

Object.defineProperty(exports, "__esModule", {
  value: true
});
exports.ImportFromUrlController = void 0;
var _ImportFromUrlController = require("./abstractions/ImportFromUrlController");
var _ImportFromUrlControllerDownloadStep = require("./importFromUrlControllerSteps/ImportFromUrlControllerDownloadStep");
var _ImportFromUrlControllerProcessEntriesStep = require("./importFromUrlControllerSteps/ImportFromUrlControllerProcessEntriesStep");
var _ImportFromUrlControllerProcessAssetsStep = require("./importFromUrlControllerSteps/ImportFromUrlControllerProcessAssetsStep");
const getDefaultStepValues = () => {
  return {
    files: [],
    triggered: false,
    finished: false,
    done: [],
    failed: [],
    invalid: [],
    aborted: []
  };
};
class ImportFromUrlController {
  async run(params) {
    const {
      context,
      response,
      input
    } = params;
    if (!input.modelId) {
      return response.error({
        message: `Missing "modelId" in the input.`,
        code: "MISSING_MODEL_ID"
      });
    } else if (Array.isArray(input.files) === false || input.files.length === 0) {
      return response.error({
        message: `No files found in the provided data.`,
        code: "NO_FILES_FOUND"
      });
    }
    try {
      await context.cms.getModel(input.modelId);
    } catch (ex) {
      return response.error({
        message: `Model "${input.modelId}" not found.`,
        code: "MODEL_NOT_FOUND"
      });
    }
    if (!input.steps) {
      input.steps = {};
    }
    const downloadStep = input.steps[_ImportFromUrlController.IImportFromUrlControllerInputStep.DOWNLOAD] || getDefaultStepValues();
    if (!downloadStep.finished) {
      const step = new _ImportFromUrlControllerDownloadStep.ImportFromUrlControllerDownloadStep();
      return await step.execute(params);
    } else if (downloadStep.failed.length) {
      return response.error({
        message: `Failed to download files.`,
        code: "FAILED_DOWNLOADING_FILES",
        data: input.steps
      });
    }
    const processEntriesStep = input.steps[_ImportFromUrlController.IImportFromUrlControllerInputStep.PROCESS_ENTRIES] || getDefaultStepValues();
    if (!processEntriesStep.finished) {
      const step = new _ImportFromUrlControllerProcessEntriesStep.ImportFromUrlControllerProcessEntriesStep();
      return await step.execute(params);
    } else if (processEntriesStep.failed.length) {
      return response.error({
        message: `Failed to process entries.`,
        code: "FAILED_PROCESSING_ENTRIES",
        data: input.steps
      });
    }
    const processAssetsStep = input.steps[_ImportFromUrlController.IImportFromUrlControllerInputStep.PROCESS_ASSETS] || getDefaultStepValues();
    if (!processAssetsStep.finished) {
      const step = new _ImportFromUrlControllerProcessAssetsStep.ImportFromUrlControllerProcessAssetsStep();
      return await step.execute(params);
    } else if (processAssetsStep.failed.length) {
      return response.error({
        message: `Failed to process assets.`,
        code: "FAILED_PROCESSING_ASSETS",
        data: input.steps
      });
    }
    const files = downloadStep.files.concat(processEntriesStep.files).concat(processAssetsStep.files);
    const output = {
      files,
      done: [],
      invalid: [],
      failed: [],
      aborted: []
    };
    return response.done(output);
  }
}
exports.ImportFromUrlController = ImportFromUrlController;

//# sourceMappingURL=ImportFromUrlController.js.map