"use strict";

Object.defineProperty(exports, "__esModule", {
  value: true
});
exports.ExportContentEntries = void 0;
var _utils = require("@webiny/tasks/utils");
var _cmsEntryZipper = require("../../utils/cmsEntryZipper");
var _createCmsEntryFetcher = require("../../utils/cmsEntryFetcher/createCmsEntryFetcher");
var _constants = require("../../constants");
class ExportContentEntries {
  constructor(config) {
    this.createCmsEntryZipper = config.createCmsEntryZipper;
  }
  async run(params) {
    const {
      context,
      response,
      input,
      isCloseToTimeout,
      isAborted
    } = params;
    const {
      prefix: basePrefix
    } = input;
    let model;
    try {
      model = await context.cms.getModel(input.modelId);
    } catch (ex) {
      return response.error({
        message: `Could not fetch entry manager for model "${input.modelId}".`,
        code: "MODEL_NOT_FOUND",
        data: {
          error: (0, _utils.getErrorProperties)(ex)
        }
      });
    }
    const prefix = `${basePrefix}/entries`;
    const fetcher = (0, _createCmsEntryFetcher.createCmsEntryFetcher)(async after => {
      const input = {
        where: params.input.where,
        limit: params.input.limit || 100000,
        sort: params.input.sort,
        after
      };
      const [items, meta] = await context.cms.listLatestEntries(model, input);
      return {
        items,
        meta
      };
    });
    const filenamePrefix = [prefix, input.after].filter(Boolean).join("-");
    const filename = `${filenamePrefix}.${_constants.WEBINY_EXPORT_ENTRIES_EXTENSION}`;
    const traverser = await context.cms.getEntryTraverser(model.modelId);
    const entryZipper = this.createCmsEntryZipper({
      filename,
      model,
      fetcher,
      traverser
    });
    const result = await entryZipper.execute({
      isCloseToTimeout,
      isAborted,
      model,
      after: input.after,
      exportAssets: input.exportAssets
    });
    const files = (input.files || []).concat([{
      key: result.key,
      checksum: result.checksum
    }]);
    if (result instanceof _cmsEntryZipper.CmsEntryZipperExecuteContinueResult) {
      return response.continue({
        ...input,
        files,
        after: result.cursor
      });
    }
    const output = {
      files
    };
    return response.done(output);
  }
}
exports.ExportContentEntries = ExportContentEntries;

//# sourceMappingURL=ExportContentEntries.js.map