"use strict";

Object.defineProperty(exports, "__esModule", {
  value: true
});
exports.PointerStore = void 0;
class PointerStore {
  isTaskAborted = false;
  isStoredFiles = false;
  constructor(params) {
    this.entryMeta = {
      cursor: params.entryMeta.cursor || null,
      hasMoreItems: true,
      totalCount: 0
    };
    this.fileCursor = params.fileCursor;
  }
  setEntryMeta(meta) {
    this.entryMeta = meta;
  }
  getEntryTotalItems() {
    return this.entryMeta?.totalCount || 0;
  }
  getEntryHasMoreItems() {
    return !!this.entryMeta?.hasMoreItems;
  }
  getEntryCursor() {
    if (!this.entryMeta?.cursor || !this.entryMeta.hasMoreItems) {
      return undefined;
    }
    return this.entryMeta.cursor;
  }
  setFileCursor(cursor) {
    this.fileCursor = cursor;
  }
  getFileCursor() {
    return this.fileCursor;
  }
  getIsStoredFiles() {
    return this.isStoredFiles;
  }
  setIsStoredFiles() {
    if (this.isStoredFiles) {
      throw new Error(`The "setIsStoredFiles" method should be called only once.`);
    }
    this.isStoredFiles = true;
  }
  getTaskIsAborted() {
    return this.isTaskAborted;
  }
  setTaskIsAborted() {
    if (this.isTaskAborted) {
      throw new Error(`The "setTaskIsAborted" method should be called only once.`);
    }
    this.isTaskAborted = true;
  }
  resetFileCursor() {
    this.fileCursor = undefined;
  }
}
exports.PointerStore = PointerStore;

//# sourceMappingURL=PointerStore.js.map